execute_over

Function execute_over 

pub async fn execute_over<B: Backend>(
    job: Job<'_>,
    tier: &Tier<B>,
    session: &mut Session,
) -> Result<Rendered, CliError>
job over tier, typing anew only what session typed otherwise; only persist commits what it offers a disk beneath.