Through

Trait Through 

pub trait Through {
    // Required methods
    fn lookup(&self, key: Hash) -> impl Future<Output = Option<Stored>>;
    fn read(
        &self,
        stored: &Stored,
        over: Extent,
    ) -> impl Future<Output = Option<Vec<Buffer>>>;
}
A store, or nothing, that a render looks a node up in and reads its samples from.

Required Methods

fn lookup(&self, key: Hash) -> impl Future<Output = Option<Stored>>

fn read( &self, stored: &Stored, over: Extent, ) -> impl Future<Output = Option<Vec<Buffer>>>

Whole chunks holding over; None where they are gone or corrupt.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Through for NoStore

Source

impl<B> Through for Store<B>
where B: Backend,