pub struct CacheStats {
pub lookups: Vec<Lookup>,
pub shed: usize,
pub bytes: u64,
pub max_bytes: u64,
pub entries: usize,
pub evictions: u64,
pub tier: Counters,
pub reached: Vec<(i64, usize)>,
pub typed: Vec<String>,
pub planned: Vec<String>,
pub unstaged: Option<String>,
pub unslotted: Option<String>,
}Expand description
Every lookup in order, or a stream’s latest, and memory as the render left it.
Fields
lookups: Vec<Lookup>shed: usizeLookups made before lookups.
bytes: u64max_bytes: u64entries: usizeevictions: u64tier: Countersreached: Vec<(i64, usize)>Each output sample a pull reached, and how many lookups had been made by then.
typed: Vec<String>planned: Vec<String>unstaged: Option<String>Why memory stopped writing to the disk meanwhile.
unslotted: Option<String>Implementations
Sourceimpl CacheStats
impl CacheStats